@@ -1,5 +1,5 @@
 # prime/engine/engine-alphabet.rb
-# $Id: engine-alphabet.rb,v 1.8 2004/12/09 12:24:15 komatsu Exp $
+# $Id: engine-alphabet.rb,v 1.10 2005/01/15 19:50:20 komatsu Exp $
 #
 # Copyright (C) 2002, 2003, 2004 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -41,6 +41,10 @@ class PrimeEngineAlphabet < PrimeEngine
     "" => "",
     "" => "Ҥ餬",
     "" => "",
+    "" => "",
+    "" => "Ҥ餬",
+    "" => "Ҥ餬",
+    "" => "",
     "|"  => "Ⱦ",
     "" => "",
     "."  => "Ⱦ",
@@ -115,8 +119,8 @@ class PrimeEngineAlphabet < PrimeEngine
 
     results.each { | word |
       if @@annotations.has_key?( word.literal ) and
-          (not word.data.has_key?('annotation')) then
-        word.data['annotation'] = @@annotations[ word.literal ]
+          (not word.data.has_key?('form')) then
+        word.data['form'] = @@annotations[ word.literal ]
       end
     }
     return results
