@@ -1,5 +1,5 @@
 # prime/engine/engine-basic.rb
-# $Id: engine-basic.rb,v 1.3 2004/03/25 17:19:50 komatsu Exp $
+# $Id: engine-basic.rb,v 1.4 2004/12/09 12:24:15 komatsu Exp $
 #
 # Copyright (C) 2002 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -14,8 +14,9 @@ require 'prime/engine/engine-sary'
 $engine_class_name = 'PrimeEngineBasic'
 
 class PrimeEngineBasic < PrimeEngineSary
-  def initialize
-    dict_file = File::join2(PRIME_DICT_DIR, 'prime-dict')
+  def initialize(dictname = 'prime-dict')
+    @dictname = dictname
+    dict_file = File::join2(PRIME_DICT_DIR, @dictname)
     super(dict_file)
 
     @name = "Basic engine"
@@ -27,8 +28,8 @@ class PrimeEngineBasic < PrimeEngineSary
     @dict         = Sary::Searcher.new(@dict_file)
     @dict_literal = Sary::Searcher.new(@dict_file, @dict_file + "_literal.ary")
 
-    file_posdict  = File::join2(PRIME_DICT_DIR, 'prime-dict-pos')
-    file_partdict = File::join2(PRIME_DICT_DIR, 'prime-dict-part')
+    file_posdict  = File::join2(PRIME_DICT_DIR, @dictname + '-pos')
+    file_partdict = File::join2(PRIME_DICT_DIR, @dictname + '-part')
     if File::exist?(file_posdict) then
       if File::exist?(file_partdict) then
         $stderr.puts("PRIME Warning:")
