@@ -1,5 +1,5 @@
 # dictformat-skk.rb: Converter module for skk format.
-# $Id: dictformat-skkdic.rb,v 1.3 2004/12/11 07:53:01 komatsu Exp $
+# $Id: dictformat-skkdic.rb,v 1.4 2004/12/31 06:23:31 komatsu Exp $
 #
 # Copyright (C) 2003 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -29,8 +29,12 @@ class DictFormatSkkdic < DictFormat
     words.each{|word|
       if valid_word?(pron, word) then
 	(literal, attr) = word.split(';')
-        comment = "comment=#{attr}"
-	results << [pron, @default_pos, literal, @default_freq, comment]
+        if attr then
+          comment = "comment=#{attr}"
+          results << [pron, @default_pos, literal, @default_freq, comment]
+        else
+          results << [pron, @default_pos, literal, @default_freq]
+        end
       end
     }
     return results
