@@ -1,5 +1,5 @@
 # server.rb
-# $Id: server.rb,v 1.2 2004/03/25 17:19:49 komatsu Exp $
+# $Id: server.rb,v 1.3 2005/01/15 19:50:20 komatsu Exp $
 #
 # Copyright (C) 2001 Satoru Takabayashi <satoru@namazu.org>
 # Copyright (C) 2004 Hiroyuki Komatsu <komatsu@taiyaki.org>
@@ -22,6 +22,9 @@ class Server
   def session_loop (io_in, io_out)
     loop {
       line = @session.get_line(io_in)
+      if line.nil? then
+        return  # The connection has been closed.
+      end
       logging(line)
       Mutex.new.synchronize {
         result = @session.execute(line)
@@ -44,6 +47,8 @@ class Server
     @debug_io.chmod(0600) if @debug_io::stat.owned?
   end
 
+  ## This method writes Line to @debug_io, if the debug mode is on.
+  ## This doesn't return any value.
   def logging (line)
     if @debug then
       line.chomp()
