@@ -1,5 +1,5 @@
 # taiyaki.rb: Ruby Libraries by Hiroyuki Komatsu
-# $Id: taiyaki.rb,v 1.7 2004/12/09 12:24:16 komatsu Exp $
+# $Id: taiyaki.rb,v 1.8 2004/12/31 06:23:32 komatsu Exp $
 #
 # Copyright (C) 2002 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -56,6 +56,7 @@ def require (name, package = nil, url = nil)
           'prime/prime-dict-config.rb' =>
                              'http://sourceforge.jp/projects/prime/',
           'suikyo/suikyo' => 'http://taiyaki.org/suikyo/',
+          'MeCab'         => 'http://chasen.org/~taku/software/mecab/',
   }
   begin
     Kernel::require(name)
@@ -84,7 +85,7 @@ def require (name, package = nil, url = nil)
       end
       $stderr.puts("  Sorry for your inconvenience.")
     end
-    exit()
+    raise(LoadError)
   end
 end
 
